@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -26,7 +26,7 @@ from pathspec import PathSpec
 from cement.utils.misc import minimal_logger
 from ebcli.objects.buildconfiguration import BuildConfiguration
 from six import StringIO
-from yaml import load, safe_dump
+from yaml import safe_load, safe_dump
 from yaml.parser import ParserError
 from yaml.scanner import ScannerError
 try:
@@ -36,8 +36,11 @@ except ImportError:
 
 from ebcli.core import io
 from ebcli.resources.strings import prompts, strings
-from ebcli.objects.exceptions import NotInitializedError, InvalidSyntaxError, \
-    NotFoundError, ValidationError
+from ebcli.objects.exceptions import (
+    NotInitializedError,
+    InvalidSyntaxError,
+    NotFoundError
+)
 from ebcli.core.ebglobals import Constants
 
 LOG = minimal_logger(__name__)
@@ -59,7 +62,6 @@ def get_ssh_folder():
 
 
 beanstalk_directory = '.elasticbeanstalk' + os.path.sep
-# TODO: Need to support yaml and yml
 buildspec_name = "buildspec.yml"
 buildspec_config_header = 'eb_codebuild_settings'
 global_config_file = beanstalk_directory + 'config.global.yml'
@@ -79,6 +81,24 @@ env_yaml = 'env.yaml'
 _marker = object()
 
 
+class ProjectRoot(object):
+    @classmethod
+    def traverse(cls):
+        cwd = os.getcwd()
+        if not os.path.isdir(beanstalk_directory):
+            LOG.debug('beanstalk directory not found in ' + cwd +
+                      '  -Going up a level')
+            os.chdir(os.path.pardir)
+
+            if cwd == os.getcwd():
+                LOG.debug('Still at the same directory ' + cwd)
+                raise NotInitializedError('EB is not yet initialized')
+
+            ProjectRoot.traverse()
+        else:
+            LOG.debug('Project root found at: ' + cwd)
+
+
 def _get_option(config, section, key, default):
     try:
         return config.get(section, key)
@@ -91,12 +111,11 @@ def is_git_directory_present():
 
 
 def clean_up():
-    # remove dir
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         if os.path.isdir(beanstalk_directory):
-            shutil.rmtree(beanstalk_directory)
+            shutil.rmtree(beanstalk_directory, ignore_errors=True)
     finally:
         os.chdir(cwd)
 
@@ -109,8 +128,8 @@ def _set_not_none(config, section, option, value):
 def get_war_file_location():
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
-        lst = glob.glob('build/libs/*.war')
+        ProjectRoot.traverse()
+        lst = glob.glob('{}'.format(os.path.join('build', 'libs', '*.war')))
         try:
             return os.path.join(os.getcwd(), lst[0])
         except IndexError:
@@ -120,10 +139,6 @@ def get_war_file_location():
         os.chdir(cwd)
 
 
-def old_eb_config_present():
-    return os.path.isfile(beanstalk_directory + 'config')
-
-
 def config_file_present():
     return os.path.isfile(local_config_file)
 
@@ -136,41 +151,6 @@ def project_file_exists(filename):
     return file_exists(project_file_path(filename))
 
 
-def get_values_from_old_eb():
-    old_config_file = beanstalk_directory + 'config'
-    config = configparser.ConfigParser()
-    config.read(old_config_file)
-
-    app_name = _get_option(config, 'global', 'ApplicationName', None)
-    cred_file = _get_option(config, 'global', 'AwsCredentialFile', None)
-    default_env = _get_option(config, 'global', 'EnvironmentName', None)
-    solution_stack_name = _get_option(config, 'global', 'SolutionStack', None)
-    region = _get_option(config, 'global', 'Region', None)
-
-    access_id, secret_key = read_old_credentials(cred_file)
-    return {'app_name': app_name,
-            'access_id': access_id,
-            'secret_key': secret_key,
-            'default_env': default_env,
-            'platform': solution_stack_name,
-            'region': region,
-            }
-
-
-def read_old_credentials(file_location):
-    if file_location is None:
-        return None, None
-    config_str = '[default]\n' + open(file_location, 'r').read()
-    config_fp = StringIO(config_str)
-
-    config = configparser.ConfigParser()
-    config.readfp(config_fp)
-
-    access_id = _get_option(config, 'default', 'AWSAccessKeyId', None)
-    secret_key = _get_option(config, 'default', 'AWSSecretKey', None)
-    return access_id, secret_key
-
-
 def save_to_aws_config(access_key, secret_key):
     config = configparser.ConfigParser()
     if not os.path.isdir(aws_config_folder):
@@ -227,9 +207,11 @@ def set_all_unrestricted_permissions(location):
     """
     os.chmod(location, stat.S_IRWXU | stat.S_IRWXG | stat.S_IRWXO)
 
+
 def remove_execute_access_from_group_and_other_users(location):
     os.chmod(location, stat.S_IRWXU | stat.S_IRGRP | stat.S_IROTH)
 
+
 def get_current_directory_name():
     dirname, filename = os.path.split(os.getcwd())
 
@@ -275,7 +257,6 @@ def get_global_value(key, default=_marker):
     if result is not None:
         return result
 
-    # get_config_setting should throw error if directory is not set up
     LOG.debug('Directory found, but no config or app name exists')
     if default is _marker:
         raise NotInitializedError
@@ -317,7 +298,6 @@ def create_config_file(
                     if dir_path
                     else beanstalk_directory)
 
-    # add to global without writing over any settings if they exist
     write_config_setting('global', 'application_name', app_name, dir_path=dir_path)
     write_config_setting('global', 'default_region', region, dir_path=dir_path)
     write_config_setting('global', 'default_platform', solution_stack, dir_path=dir_path)
@@ -330,38 +310,27 @@ def create_config_file(
     gitops.set_branch_default_for_current_environment(branch)
 
 
-def _traverse_to_project_root():
-    cwd = os.getcwd()
-    if not os.path.isdir(beanstalk_directory):
-        LOG.debug('beanstalk directory not found in ' + cwd +
-                  '  -Going up a level')
-        os.chdir(os.path.pardir)  # Go up one directory
-
-        if cwd == os.getcwd():  # We can't move any further
-            LOG.debug('Still at the same directory ' + cwd)
-            raise NotInitializedError('EB is not yet initialized')
-
-        _traverse_to_project_root()
-
-    else:
-        LOG.debug('Project root found at: ' + cwd)
-
-
 def get_project_root():
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         return os.getcwd()
     finally:
         os.chdir(cwd)
 
 
+def inside_ebcli_project():
+    try:
+        return not not get_project_root()
+    except NotInitializedError:
+        return False
+
+
 def get_zip_location(file_name):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         if not os.path.isdir(app_version_folder):
-            # create it
             os.makedirs(app_version_folder)
 
         return os.path.abspath(app_version_folder) + os.path.sep + file_name
@@ -373,9 +342,8 @@ def get_zip_location(file_name):
 def get_logs_location(folder_name):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         if not os.path.isdir(logs_folder):
-            # create it
             os.makedirs(logs_folder)
 
         return os.path.abspath(os.path.join(logs_folder, folder_name))
@@ -393,7 +361,6 @@ def os_which(program):
     for p in path.split(os.path.pathsep):
         p = os.path.join(p, program)
         if sys.platform.startswith('win'):
-            # Add .exe for windows
             p += '.exe'
         if os.path.exists(p) and os.access(p, os.X_OK):
             return p
@@ -406,21 +373,21 @@ def delete_file(location):
 
 def delete_directory(location):
     if os.path.isdir(location):
-        shutil.rmtree(location)
+        shutil.rmtree(location, ignore_errors=True)
 
 
 def delete_app_versions():
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         delete_directory(app_version_folder)
     finally:
         os.chdir(cwd)
 
 
 def zip_append_archive(target_file, source_file):
-    zip_source = zipfile.ZipFile(source_file, 'r')
-    zip_target = zipfile.ZipFile(target_file, 'a')
+    zip_source = zipfile.ZipFile(source_file, 'r', allowZip64=True)
+    zip_target = zipfile.ZipFile(target_file, 'a', allowZip64=True)
     with warnings.catch_warnings():
         # Ignore UserWarning raised by zip module for zipping modules.
         warnings.simplefilter('ignore', category=UserWarning)
@@ -436,7 +403,7 @@ def zip_up_folder(directory, location, ignore_list=None):
     try:
         os.chdir(directory)
         io.log_info('Zipping up folder at location: ' + str(os.getcwd()))
-        zipf = zipfile.ZipFile(location, 'w', zipfile.ZIP_DEFLATED)
+        zipf = zipfile.ZipFile(location, 'w', zipfile.ZIP_DEFLATED, allowZip64=True)
         _zipdir('./', zipf, ignore_list=ignore_list)
         zipf.close()
         LOG.debug('File size: ' + str(os.path.getsize(location)))
@@ -448,7 +415,7 @@ def zip_up_project(location, ignore_list=None):
     cwd = os.getcwd()
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         zip_up_folder('./', location, ignore_list=ignore_list)
 
@@ -458,8 +425,8 @@ def zip_up_project(location, ignore_list=None):
 
 def _zipdir(path, zipf, ignore_list=None):
     if ignore_list is None:
-        ignore_list = ['.gitignore']
-    ignore_list = ['./' + i for i in ignore_list]
+        ignore_list = {'.gitignore'}
+    ignore_list = {'./' + i for i in ignore_list}
     zipped_roots = []
     for root, dirs, files in os.walk(path):
         if '.elasticbeanstalk' in root:
@@ -468,13 +435,13 @@ def _zipdir(path, zipf, ignore_list=None):
         for d in dirs:
             cur_dir = os.path.join(root, d)
             if os.path.islink(cur_dir):
+                # It is probably safe to remove this code since os.walk seems to categorize
+                # symlinks-to-directories as files. This doesn't matter as far as creation
+                # of the zip is concerned, but just having the code around is confusing.
                 zipInfo = zipfile.ZipInfo()
                 zipInfo.filename = os.path.join(root, d)
 
                 # 2716663808L is the "magic code" for symlinks
-
-                # Python 3 merged "int" and "long" into int, so we must check the version
-                # to determine what type to use
                 if sys.version_info > (3,):
                     zipInfo.external_attr = 2716663808
                 else:
@@ -496,11 +463,7 @@ def _zipdir(path, zipf, ignore_list=None):
                 if os.path.islink(cur_file):
                     zipInfo = zipfile.ZipInfo()
                     zipInfo.filename = os.path.join(root, f)
-                    
-                    # 2716663808L is the "magic code" for symlinks
 
-                    # Python 3 merged "int" and "long" into int, so we must check the
-                    # version to determine what type to use
                     if sys.version_info > (3,):
                         zipInfo.external_attr = 2716663808
                     else:
@@ -514,7 +477,7 @@ def unzip_folder(file_location, directory):
     if not os.path.isdir(directory):
         os.makedirs(directory)
 
-    zip = zipfile.ZipFile(file_location, 'r')
+    zip = zipfile.ZipFile(file_location, 'r', allowZip64=True)
     for cur_file in zip.namelist():
         if not cur_file.endswith('/'):
             root, name = os.path.split(cur_file)
@@ -524,24 +487,12 @@ def unzip_folder(file_location, directory):
             open(os.path.join(path, name), 'wb').write(zip.read(cur_file))
 
 
-def save_to_file(data, location, filename):
-    if not os.path.isdir(location):
-        os.makedirs(location)
-
-    file_location = os.path.join(location, filename)
-    data_file = open(file_location, 'wb')
-    data_file.write(data)
-
-    data_file.close()
-    return file_location
-
-
 def delete_app_file(app_name):
     cwd = os.getcwd()
     file_name = beanstalk_directory + app_name
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         for file_ext in ['.app.yml']:
             path = file_name + file_ext
             delete_file(path)
@@ -554,7 +505,7 @@ def delete_env_file(env_name):
     file_name = beanstalk_directory + env_name
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         for file_ext in ['.ebe.yml', '.env.yml']:
             path = file_name + file_ext
             delete_file(path)
@@ -570,7 +521,7 @@ def get_editor():
         platform = sys.platform
         windows = platform.startswith('win')
         if windows:
-            editor = None
+            editor = 'notepad.exe'
         else:
             editor = 'nano'
 
@@ -580,12 +531,11 @@ def get_editor():
 def save_app_file(app):
     cwd = os.getcwd()
     env_name = app['ApplicationName']
-    # ..yml extension helps editors enable syntax highlighting
     file_name = env_name + '.app.yml'
 
     file_name = beanstalk_directory + file_name
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         file_name = os.path.abspath(file_name)
 
@@ -602,12 +552,11 @@ def save_app_file(app):
 def save_env_file(env):
     cwd = os.getcwd()
     env_name = env['EnvironmentName']
-    # ..yml extension helps editors enable syntax highlighting
     file_name = env_name + '.env.yml'
 
     file_name = beanstalk_directory + file_name
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         file_name = os.path.abspath(file_name)
 
@@ -626,12 +575,12 @@ def get_environment_from_file(env_name):
     file_name = beanstalk_directory + env_name
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         file_ext = '.env.yml'
         path = file_name + file_ext
         if os.path.exists(path):
             with codecs.open(path, 'r', encoding='utf8') as f:
-                env = load(f)
+                return safe_load(f)
     except (ScannerError, ParserError):
         raise InvalidSyntaxError('The environment file contains '
                                  'invalid syntax.')
@@ -639,20 +588,18 @@ def get_environment_from_file(env_name):
     finally:
         os.chdir(cwd)
 
-    return env
-
 
 def get_application_from_file(app_name):
     cwd = os.getcwd()
     file_name = beanstalk_directory + app_name
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         file_ext = '.app.yml'
         path = file_name + file_ext
         if os.path.exists(path):
             with codecs.open(path, 'r', encoding='utf8') as f:
-                app = load(f)
+                return safe_load(f)
     except (ScannerError, ParserError):
         raise InvalidSyntaxError('The application file contains '
                                  'invalid syntax.')
@@ -660,8 +607,6 @@ def get_application_from_file(app_name):
     finally:
         os.chdir(cwd)
 
-    return app
-
 
 def update_platform_version(version):
     if version:
@@ -682,11 +627,11 @@ def get_keyname():
 
 
 def write_config_setting(section, key_name, value, dir_path=None, file=local_config_file):
-    cwd = os.getcwd()  # save working directory
+    cwd = os.getcwd()
     if dir_path:
         os.chdir(dir_path)
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         config = _get_yaml_dict(file)
         if not config:
@@ -705,15 +650,14 @@ def write_config_setting(section, key_name, value, dir_path=None, file=local_con
                               line_break=os.linesep))
 
     finally:
-        os.chdir(cwd)  # go back to working directory
+        os.chdir(cwd)
 
 
 def get_config_setting(section, key_name, default=_marker):
-    # get setting from global if it exists
-    cwd = os.getcwd()  # save working directory
+    cwd = os.getcwd()
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         config_global = _get_yaml_dict(global_config_file)
         config_local = _get_yaml_dict(local_config_file)
@@ -728,7 +672,7 @@ def get_config_setting(section, key_name, default=_marker):
             if config_local:
                 value = config_local[section][key_name]
         except KeyError:
-            pass  # Revert to global value
+            pass
 
         if value is None and default != _marker:
             return default
@@ -738,7 +682,7 @@ def get_config_setting(section, key_name, default=_marker):
         else:
             return default
     finally:
-        os.chdir(cwd)  # move back to working directory
+        os.chdir(cwd)
     return value
 
 
@@ -764,7 +708,7 @@ def write_json_dict(json_data, fullpath):
 def _get_yaml_dict(filename):
     try:
         with codecs.open(filename, 'r', encoding='utf8') as f:
-            return load(f)
+            return safe_load(f)
     except IOError:
         return {}
 
@@ -776,7 +720,7 @@ def file_exists(full_path):
 def eb_file_exists(location):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         path = beanstalk_directory + location
         return os.path.isfile(path)
     finally:
@@ -786,60 +730,59 @@ def eb_file_exists(location):
 def build_spec_exists():
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         return os.path.isfile(buildspec_name)
     finally:
         os.chdir(cwd)
 
 
 def get_build_configuration():
-    # Values expected in the eb config section in BuildSpec
     service_role_key = 'CodeBuildServiceRole'
     image_key = 'Image'
     compute_key = 'ComputeType'
     timeout_key = 'Timeout'
 
-    # get setting from global if it exists
-    cwd = os.getcwd()  # save working directory
+    cwd = os.getcwd()
 
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
 
         build_spec = _get_yaml_dict(buildspec_name)
 
-        # Assert that special beanstalk section exists
         if build_spec is None or buildspec_config_header not in build_spec.keys():
             LOG.debug("Buildspec Keys: {0}".format(build_spec.keys()))
             io.log_warning(strings['codebuild.noheader'].replace('{header}', buildspec_config_header))
             return None
 
-        build_configuration = BuildConfiguration()
         beanstalk_build_configs = build_spec[buildspec_config_header]
 
         if beanstalk_build_configs is None:
             LOG.debug("No values for EB header in buildspec file")
-            return build_configuration
+            return BuildConfiguration()
 
         LOG.debug("EB Config Keys: {0}".format(beanstalk_build_configs.keys()))
 
-        if service_role_key in beanstalk_build_configs.keys():
-            build_configuration.service_role = beanstalk_build_configs[service_role_key]
-
-        if image_key in beanstalk_build_configs.keys():
-            build_configuration.image = beanstalk_build_configs[image_key]
-
-        if compute_key in beanstalk_build_configs.keys():
-            build_configuration.compute_type = beanstalk_build_configs[compute_key]
-
-        if timeout_key in beanstalk_build_configs.keys():
-            build_configuration.timeout = beanstalk_build_configs[timeout_key]
-
+        build_configuration = BuildConfiguration(
+            compute_type=beanstalk_build_configs.get(compute_key),
+            image=beanstalk_build_configs.get(image_key),
+            service_role=beanstalk_build_configs.get(service_role_key),
+            timeout=beanstalk_build_configs.get(timeout_key)
+        )
     finally:
-        os.chdir(cwd)  # move back to working directory
+        os.chdir(cwd)
 
     return build_configuration
 
 
+def write_buildspec_config_header(key_name, value):
+    write_config_setting(
+        buildspec_config_header,
+        key_name,
+        value,
+        file=buildspec_name
+    )
+
+
 def directory_empty(location):
     return not os.listdir(location)
 
@@ -853,8 +796,8 @@ def get_ebignore_list():
     with codecs.open(location, 'r', encoding='utf-8') as f:
         spec = PathSpec.from_lines('gitwildmatch', f)
 
-    ignore_list = [f for f in spec.match_tree(get_project_root())]
-    ignore_list.append('.ebignore')
+    ignore_list = {f for f in spec.match_tree(get_project_root())}
+    ignore_list.add('.ebignore')
 
     return ignore_list
 
@@ -862,7 +805,7 @@ def get_ebignore_list():
 def make_eb_dir(location):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         path = beanstalk_directory + location
         if not os.path.isdir(path):
             os.makedirs(path)
@@ -873,23 +816,13 @@ def make_eb_dir(location):
 def write_to_eb_data_file(location, data):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         path = beanstalk_directory + location
         write_to_data_file(path, data)
     finally:
         os.chdir(cwd)
 
 
-def read_from_eb_data_file(location):
-    cwd = os.getcwd()
-    try:
-        _traverse_to_project_root()
-        path = beanstalk_directory + location
-        read_from_data_file(path)
-    finally:
-        os.chdir(cwd)
-
-
 def write_to_data_file(location, data):
     with codecs.open(location, 'wb', encoding=None) as f:
         f.write(data)
@@ -923,7 +856,7 @@ def readlines_from_text_file(location):
 def get_project_file_full_location(location):
     cwd = os.getcwd()
     try:
-        _traverse_to_project_root()
+        ProjectRoot.traverse()
         full_path = os.path.abspath(location)
         return full_path
     finally:
@@ -946,7 +879,6 @@ def get_filename_without_extension(file_location):
     filename = os.path.basename(file_location)
     extension = 'fake'
     while extension != '':
-        # Split multiple extensions
         filename, extension = os.path.splitext(filename)
     return filename
 
@@ -957,7 +889,7 @@ def env_yaml_exists():
 
 def get_env_name_from_env_yaml():
     with open(os.path.join(os.getcwd(), env_yaml), 'r') as f:
-        data = yaml.load(f)
+        data = yaml.safe_load(f)
         try:
             env_name = data['EnvironmentName']
             return env_name
@@ -967,7 +899,7 @@ def get_env_name_from_env_yaml():
 
 def get_platform_from_env_yaml():
     with open(os.path.join(os.getcwd(), env_yaml), 'r') as f:
-        data = yaml.load(f)
+        data = yaml.safe_load(f)
         try:
             env_name = data['SolutionStack']
             return env_name
@@ -976,17 +908,14 @@ def get_platform_from_env_yaml():
 
 
 def open_file_for_editing(file_location):
-    # Added this line for windows whitespace escaping
     file_location = '"{0}"'.format(file_location)
     editor = get_editor()
-    if editor:
-        try:
-            os.system(editor + ' ' + file_location)
-        except OSError:
-            io.log_error(prompts['fileopen.error1'].replace('{editor}',
-                                                            editor))
-    else:
-        try:
-            os.system(file_location)
-        except OSError:
-            io.log_error(prompts['fileopen.error2'])
+    try:
+        os.system(editor + ' ' + file_location)
+    except OSError:
+        io.log_error(
+            prompts['fileopen.error1'].replace(
+                '{editor}',
+                editor
+            )
+        )
