@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -18,20 +18,20 @@ import warnings
 
 import botocore
 import botocore.exceptions
+import botocore.parsers
 import botocore.session
 from botocore.config import Config
 from botocore.loaders import Loader
 from cement.utils.misc import minimal_logger
 
 from ebcli import __version__
-from .botopatch import apply_patches
-from .utils import static_var
-from ..core import fileoperations
-from ..objects.exceptions import ServiceError, NotAuthorizedError, \
+from ebcli.lib.botopatch import apply_patches
+from ebcli.lib.utils import static_var
+from ebcli.objects.exceptions import ServiceError, NotAuthorizedError, \
     CredentialsError, NoRegionError,  ValidationError, \
     InvalidProfileError, ConnectionError, AlreadyExistsError, NotFoundError, \
     NotAuthorizedInRegionError
-from ..resources.strings import strings
+from ebcli.resources.strings import strings
 
 LOG = minimal_logger(__name__)
 
@@ -83,16 +83,16 @@ def set_profile(profile):
 def get_profile():
     if _profile is not None:
         return _profile
-    from ..operations import commonops
+    from ebcli.operations import commonops
     return commonops.get_default_profile(require_default=True)
 
+
 def set_region(region_name):
     global _region_name
     _region_name = region_name
 
     # Invalidate session and old clients
     _get_botocore_session.botocore_session = None
-    _api_clients = {}
 
 
 def set_endpoint_url(endpoint_url):
@@ -120,6 +120,7 @@ def _set_user_agent_for_session(session):
     session.user_agent_name = 'eb-cli'
     session.user_agent_version = __version__
 
+
 def _get_data_loader():
     # Creates a botocore data loader that loads custom data files
     # FIRST, creating a precedence for custom files.
@@ -129,6 +130,7 @@ def _get_data_loader():
     return Loader(extra_search_paths=[data_folder, Loader.BUILTIN_DATA_PATH],
                   include_default_search_paths=False)
 
+
 def _get_client(service_name):
     aws_access_key_id = _id
     aws_secret_key = _key
@@ -144,7 +146,6 @@ def _get_client(service_name):
         LOG.debug('Creating new Botocore Client for ' + str(service_name))
         client = session.create_client(service_name,
                                        endpoint_url=endpoint_url,
-                                       # region_name=_region_name,
                                        aws_access_key_id=aws_access_key_id,
                                        aws_secret_access_key=aws_secret_key,
                                        verify=_verify_ssl,
@@ -167,6 +168,7 @@ def _get_botocore_session():
             'profile': (None, _profile_env_var, _profile, None),
         })
         session.set_config_variable('region', _region_name)
+        session.set_config_variable('profile', _profile)
         session.register_component('data_loader', _get_data_loader())
         _set_user_agent_for_session(session)
         _get_botocore_session.botocore_session = session
@@ -191,6 +193,7 @@ def get_credentials():
 def make_api_call(service_name, operation_name, **operation_options):
     operation = _set_operation(service_name, operation_name)
     aggregated_error_message = []
+    max_attempts = 10
 
     region = _region_name
     if not region:
@@ -201,8 +204,7 @@ def make_api_call(service_name, operation_name, **operation_options):
         attempt += 1
         if attempt > 1:
             LOG.debug('Retrying -- attempt #' + str(attempt))
-        delay = _get_delay(attempt)
-        time.sleep(delay)
+        _sleep(_get_delay(attempt))
         try:
             LOG.debug('Making api call: (' +
                       service_name + ', ' + operation_name +
@@ -217,7 +219,15 @@ def make_api_call(service_name, operation_name, **operation_options):
 
         except botocore.exceptions.ClientError as e:
             _handle_response_code(e.response, attempt, aggregated_error_message)
+        except botocore.parsers.ResponseParserError as e:
+            LOG.debug('Botocore could not parse response received')
+            if attempt > max_attempts:
+                raise MaxRetriesError(
+                    'Max retries exceeded for ResponseParserErrors'
+                    + os.linesep.join(aggregated_error_message)
+                )
 
+            aggregated_error_message.insert(attempt, str(e))
         except botocore.exceptions.NoCredentialsError:
             LOG.debug('No credentials found')
             raise CredentialsError('Operation Denied. You appear to have no'
@@ -230,7 +240,7 @@ def make_api_call(service_name, operation_name, **operation_options):
                 botocore.exceptions.ParamValidationError) as e:
             raise ValidationError(str(e))
 
-        except botocore.exceptions.BotoCoreError as e:
+        except botocore.exceptions.BotoCoreError:
             LOG.error('Botocore Error')
             raise
 
@@ -255,7 +265,6 @@ def _handle_response_code(response_data, attempt, aggregated_error_message):
     except KeyError:
         message = ""
     if status == 400:
-        # Convert to correct 400 error
         error = _get_400_error(response_data, message)
         if isinstance(error, ThrottlingError):
             LOG.debug('Received throttling error')
@@ -282,7 +291,11 @@ def _handle_response_code(response_data, attempt, aggregated_error_message):
         raise AlreadyExistsError(message)
     elif status in (500, 503, 504):
         LOG.debug('Received 5XX error')
-        retry_failure_message = 'Received 5XX error during attempt #{0}\n   {1}\n'.format(str(attempt), message)
+        retry_failure_message = \
+            'Received 5XX error during attempt #{0}\n   {1}\n'.format(
+                str(attempt),
+                message
+            )
 
         aggregated_error_message.insert(attempt, retry_failure_message)
 
@@ -342,15 +355,19 @@ def _get_400_error(response_data, message):
         ]
         return TooManyConfigurationTemplatesException(' '.join(message))
     else:
-        # Not tracking this error
         return ServiceError(message, code=code)
 
+
 def _handle_500_error(aggregated_error_message):
     raise MaxRetriesError('Max retries exceeded for '
                           'service error (5XX)\n' +
                           aggregated_error_message)
 
 
+def _sleep(delay):
+    time.sleep(delay)
+
+
 class InvalidParameterValueError(ServiceError):
     pass
 
