@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -31,6 +31,9 @@ def get_all_regions():
         Region('ca-central-1', 'Canada (Central)'),
         Region('eu-west-2', 'EU (London)'),
         Region('eu-west-3', 'EU (Paris)'),
+        Region('eu-north-1', 'EU (Stockholm)'),
+        Region('ap-east-1', 'Asia Pacific (Hong Kong)'),
+        Region('me-south-1', 'Middle East (Bahrain)'),
     ]
 
 
