@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,10 +10,44 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import copy
+
+from ebcli.objects.solutionstack import SolutionStack
+from ebcli.objects.platform import PlatformVersion
+from ebcli.resources.strings import strings
+from ebcli.resources.statics import namespaces, option_names
+
+
+class OptionSetting(object):
+    def __init__(self, namespace, option_name, value):
+        self.namespace = namespace
+        self.option_name = option_name
+        self.value = value
+
+    def __eq__(self, other):
+        return self.__hash__() == other.__hash__()
+
+    def __hash__(self):
+        """
+        __hash__ method for `OptionSetting` to enable comparison of sets of `OptionSetting`s objects.
+        :return: a hash of the `tuple` of the `OptionSetting` attributes
+        """
+        return hash((self.namespace, self.option_name, self.value))
+
+    @classmethod
+    def option_settings_from_json(cls, json_array):
+        option_settings = set()
+        for option_setting in json_array:
+            option_settings.add(
+                OptionSetting(
+                    namespace=option_setting['Namespace'],
+                    option_name=option_setting['OptionName'],
+                    value=option_setting['Value'],
+                )
+            )
+
+        return option_settings
 
-from ..lib import ec2, utils
-from ..resources.strings import strings
-from ..resources.statics import namespaces, option_names
 
 class CreateEnvironmentRequest(object):
 
@@ -23,7 +57,10 @@ class CreateEnvironmentRequest(object):
                  single_instance=False, key_name=None,
                  sample_application=False, tags=None, scale=None,
                  database=None, vpc=None, template_name=None, group_name=None,
-                 elb_type=None, platform_arn=None):
+                 elb_type=None, enable_spot=None, instance_types=None,
+                 spot_max_price=None, on_demand_base_capacity=None,
+                 on_demand_above_base_capacity=None, min_instances=None,
+                 max_instances=None):
         self.app_name = app_name
         self.cname = cname
         self.env_name = env_name
@@ -37,7 +74,6 @@ class CreateEnvironmentRequest(object):
         self.template_name = template_name
         self.tier = tier
         self.version_label = version_label
-        self.platform_arn = platform_arn
         self.group_name = group_name
         if tags is None:
             self.tags = []
@@ -57,6 +93,13 @@ class CreateEnvironmentRequest(object):
         self.option_settings = []
         self.compiled = False
         self.description = strings['env.description']
+        self.enable_spot = enable_spot
+        self.instance_types = instance_types
+        self.spot_max_price = spot_max_price
+        self.on_demand_base_capacity = on_demand_base_capacity
+        self.on_demand_above_base_capacity = on_demand_above_base_capacity
+        self.min_instances = min_instances
+        self.max_instances = max_instances
 
         if not self.app_name:
             raise TypeError(self.__class__.__name__ + ' requires key-word argument app_name')
@@ -70,10 +113,20 @@ class CreateEnvironmentRequest(object):
                 self.scale = str(scale)
 
     def __eq__(self, other):
-        return self.__dict__ == other.__dict__
+        self_dict = copy.deepcopy(self.__dict__)
+        other_dict = copy.deepcopy(other.__dict__)
+
+        self_dict['option_settings'] = OptionSetting.option_settings_from_json(
+            self_dict.get('option_settings', [])
+        )
+        other_dict['option_settings'] = OptionSetting.option_settings_from_json(
+            other_dict.get('option_settings', [])
+        )
+
+        return self_dict == other_dict
 
     def __ne__(self, other):
-        return self.__dict__ != other.__dict__
+        return not self == other
 
     def add_option_setting(self, namespace, option_name, value, resource=None):
         setting = {'Namespace': namespace,
@@ -93,6 +146,7 @@ class CreateEnvironmentRequest(object):
             self.add_client_defaults()
             self.compile_database_options()
             self.compile_vpc_options()
+            self.compile_spot_options()
             self.compile_common_options()
             self.compiled = True
 
@@ -103,9 +157,10 @@ class CreateEnvironmentRequest(object):
             'OptionSettings': self.option_settings,
             }
         if self.platform:
-            kwargs['SolutionStackName'] = self.platform.name
-        if self.platform_arn:
-            kwargs['PlatformArn'] = self.platform_arn
+            if isinstance(self.platform, SolutionStack):
+                kwargs['SolutionStackName'] = self.platform.name
+            elif isinstance(self.platform, PlatformVersion):
+                kwargs['PlatformArn'] = self.platform.name
         if self.description:
             kwargs['Description'] = self.description
         if self.cname:
@@ -117,7 +172,7 @@ class CreateEnvironmentRequest(object):
         if self.tags:
             kwargs['Tags'] = self.tags
         if self.tier:
-            kwargs['Tier'] = self.tier.to_struct()
+            kwargs['Tier'] = self.tier.to_dict()
 
         if self.scale:
             self.add_option_setting(
@@ -167,6 +222,16 @@ class CreateEnvironmentRequest(object):
                 namespaces.AUTOSCALING,
                 option_names.MIN_SIZE,
                 self.scale)
+        if self.min_instances:
+            self.add_option_setting(
+                namespaces.AUTOSCALING,
+                option_names.MIN_SIZE,
+                self.min_instances)
+        if self.max_instances:
+            self.add_option_setting(
+                namespaces.AUTOSCALING,
+                option_names.MAX_SIZE,
+                self.max_instances)
         if self.elb_type:
             self.add_option_setting(
                 namespaces.ENVIRONMENT,
@@ -175,17 +240,8 @@ class CreateEnvironmentRequest(object):
 
     def add_client_defaults(self):
         if self.template_name:
-            # dont add client defaults if a template is being used
             return
 
-        if not self.instance_type:
-            if ec2.has_default_vpc():
-                # Launch with t2 micro if not a classic account
-                self.add_option_setting(
-                    namespaces.LAUNCH_CONFIGURATION,
-                    option_names.INSTANCE_TYPE,
-                    't2.micro'
-                )
         if self.platform and self.platform.has_healthd_support:
             self.add_option_setting(
                 namespaces.HEALTH_SYSTEM,
@@ -250,10 +306,15 @@ class CreateEnvironmentRequest(object):
         namespace = namespaces.VPC
         self.add_option_setting(namespace, option_names.VPC_ID,
                                 self.vpc['id'])
-        self.add_option_setting(namespace, option_names.PUBLIC_IP,
-                                self.vpc['publicip'])
-        self.add_option_setting(namespace, option_names.ELB_SCHEME,
-                                self.vpc['elbscheme'])
+        if self.vpc['publicip']:
+            self.add_option_setting(
+                namespace,
+                option_names.PUBLIC_IP,
+                self.vpc['publicip']
+            )
+        if self.vpc['elbscheme']:
+            self.add_option_setting(namespace, option_names.ELB_SCHEME,
+                                    self.vpc['elbscheme'])
         if self.vpc['elbsubnets']:
             self.add_option_setting(namespace, option_names.ELB_SUBNETS,
                                     self.vpc['elbsubnets'])
@@ -268,22 +329,52 @@ class CreateEnvironmentRequest(object):
             self.add_option_setting(namespace, option_names.DB_SUBNETS,
                                     self.vpc['dbsubnets'])
 
+    def compile_spot_options(self):
+        if not self.enable_spot:
+            return
+
+        namespace = namespaces.SPOT
+        self.add_option_setting(namespace, option_names.ENABLE_SPOT, 'true')
+
+        if self.instance_types:
+            self.add_option_setting(
+                namespaces.SPOT,
+                option_names.INSTANCE_TYPES,
+                self.instance_types)
+
+        if self.on_demand_base_capacity:
+            self.add_option_setting(namespace, option_names.ON_DEMAND_BASE_CAPACITY, self.on_demand_base_capacity)
+
+        if self.on_demand_above_base_capacity:
+            self.add_option_setting(namespace, option_names.ON_DEMAND_PERCENTAGE_ABOVE_BASE_CAPACITY, self.on_demand_above_base_capacity)
+
+        if self.spot_max_price:
+            self.add_option_setting(namespace, option_names.SPOT_MAX_PRICE, self.spot_max_price)
+
+        if self.on_demand_base_capacity:
+            self.add_option_setting(namespace, option_names.ON_DEMAND_BASE_CAPACITY, self.on_demand_base_capacity)
+
+        if self.on_demand_above_base_capacity:
+            self.add_option_setting(
+                namespace,
+                option_names.ON_DEMAND_PERCENTAGE_ABOVE_BASE_CAPACITY,
+                self.on_demand_above_base_capacity)
+
 
 class CloneEnvironmentRequest(CreateEnvironmentRequest):
     def __init__(self, app_name=None, env_name=None, original_name=None,
-                 cname=None, platform=None, scale=None, tags=None, platform_arn=None):
+                 cname=None, platform=None, scale=None, tags=None):
         if not original_name:
             raise TypeError(self.__class__.__name__ + ' requires key-word argument clone_name')
         self.original_name = original_name
         super(CloneEnvironmentRequest, self).__init__(
             app_name=app_name, env_name=env_name, cname=cname,
-            platform=platform, scale=scale, tags=tags, platform_arn=platform_arn
+            platform=platform, scale=scale, tags=tags
         )
         self.description = strings['env.clonedescription']. \
             replace('{env-name}', self.env_name)
 
     def compile_option_settings(self):
         if not self.compiled:
-            # dont compile extras like vpc/database/etc.
             self.compile_common_options()
             self.compiled = True
