@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -16,11 +16,11 @@ import os
 
 from cement.utils.misc import minimal_logger
 
-from ..lib import ec2, utils
-from ..objects.exceptions import NoKeypairError, NotFoundError, CommandError, InvalidOptionsError
-from ..resources.strings import strings, prompts
-from ..core import io, fileoperations
-from . import commonops
+from ebcli.lib import ec2, utils
+from ebcli.objects.exceptions import NoKeypairError, NotFoundError, CommandError, InvalidOptionsError
+from ebcli.resources.strings import strings, prompts
+from ebcli.core import io, fileoperations
+from ebcli.operations import commonops
 
 
 LOG = minimal_logger(__name__)
@@ -28,16 +28,16 @@ LOG = minimal_logger(__name__)
 
 def prepare_for_ssh(env_name, instance, keep_open, force, setup, number,
                     keyname=None, no_keypair_error_message=None,
-                    custom_ssh=None, command=None):
+                    custom_ssh=None, command=None, timeout=None):
     if setup:
-        setup_ssh(env_name, keyname)
+        setup_ssh(env_name, keyname, timeout=timeout)
         return
 
     if instance and number:
         raise InvalidOptionsError(strings['ssh.instanceandnumber'])
 
     if not instance:
-        instances = commonops.get_instance_ids(None, env_name)
+        instances = commonops.get_instance_ids(env_name)
         if number is not None:
             if number > len(instances) or number < 1:
                 raise InvalidOptionsError(
@@ -55,15 +55,20 @@ def prepare_for_ssh(env_name, instance, keep_open, force, setup, number,
             instance = utils.prompt_for_item_in_list(instances)
 
     try:
-        ssh_into_instance(instance, keep_open=keep_open, force_open=force, custom_ssh=custom_ssh, command=command)
+        ssh_into_instance(
+            instance,
+            keep_open=keep_open,
+            force_open=force,
+            custom_ssh=custom_ssh,
+            command=command
+        )
     except NoKeypairError:
         if not no_keypair_error_message:
             no_keypair_error_message = prompts['ssh.nokey']
         io.log_error(no_keypair_error_message)
 
 
-def setup_ssh(env_name, keyname):
-    # Instance does not have a keypair
+def setup_ssh(env_name, keyname, timeout=None):
     io.log_warning(prompts['ssh.setupwarn'].replace('{env-name}',
                                                     env_name))
 
@@ -75,7 +80,7 @@ def setup_ssh(env_name, keyname):
              'OptionName': 'EC2KeyName',
              'Value': keyname}
         ]
-        commonops.update_environment(env_name, options, False)
+        commonops.update_environment(env_name, options, False, timeout=timeout or 5)
 
 
 def ssh_into_instance(instance_id, keep_open=False, force_open=False, custom_ssh=None, command=None):
@@ -87,27 +92,23 @@ def ssh_into_instance(instance_id, keep_open=False, force_open=False, custom_ssh
     try:
         ip = instance['PublicIpAddress']
     except KeyError:
-        # Now allows access to private subnet
-        if 'PrivateIpAddress' in instance and 'PrivateDnsName' in instance:
-            ip = instance['PrivateDnsName']
+        if 'PrivateIpAddress' in instance:
+            ip = instance['PrivateIpAddress']
         else:
             raise NotFoundError(strings['ssh.noip'])
     security_groups = instance['SecurityGroups']
 
     user = 'ec2-user'
 
-    # Get security group to open
     ssh_group = None
     has_restriction = False
     rule_existed_before = False
     group_id = None
     for group in security_groups:
         group_id = group['GroupId']
-        # see if group has ssh rule
         group = ec2.describe_security_group(group_id)
         for permission in group.get('IpPermissions', []):
             if permission.get('ToPort', None) == 22:
-                # SSH Port group
                 ssh_group = group_id
                 for rng in permission.get('IpRanges', []):
                     ip_restriction = rng.get('CidrIp', None)
@@ -117,16 +118,13 @@ def ssh_into_instance(instance_id, keep_open=False, force_open=False, custom_ssh
                         elif ip_restriction == '0.0.0.0/0':
                             rule_existed_before = True
 
-
     if has_restriction and not force_open:
         io.log_warning(strings['ssh.notopening'])
     elif group_id:
-        # Open up port for ssh
         io.echo(strings['ssh.openingport'])
         ec2.authorize_ssh(ssh_group or group_id)
         io.echo(strings['ssh.portopen'])
 
-    # do ssh
     try:
         if custom_ssh:
             custom_ssh = custom_ssh.split()
@@ -147,7 +145,6 @@ def ssh_into_instance(instance_id, keep_open=False, force_open=False, custom_ssh
     except OSError:
         CommandError(strings['ssh.notpresent'])
     finally:
-        # Close port for ssh
         if keep_open:
             pass
         elif (not has_restriction or force_open) and group_id and not rule_existed_before:
@@ -185,7 +182,6 @@ def prompt_for_ec2_keyname(env_name=None, message=None, keyname=None):
     if keyname:
         for index, key in enumerate(keys):
             if key == keyname:
-                # The selection is between 1 and len(keys)
                 default_option = index + 1
 
     if len(keys) < 1:
@@ -205,7 +201,6 @@ def prompt_for_ec2_keyname(env_name=None, message=None, keyname=None):
 
 
 def _generate_and_upload_keypair(keys):
-    # Get filename
     io.echo()
     io.echo(prompts['keypair.nameprompt'])
     unique = utils.get_unique_name('aws-eb', keys)
@@ -220,8 +215,6 @@ def _generate_and_upload_keypair(keys):
         raise CommandError(strings['ssh.notpresent'])
 
     if exitcode == 0 or exitcode == 1:
-        # if exitcode is 1, they file most likely exists, and they are
-        ## just uploading it
         commonops.upload_keypair_if_needed(keyname)
         return keyname
     else:
